// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_http_client/src/middleware.dart';
import 'package:wyatt_http_client/src/models/middleware_context.dart';
import 'package:wyatt_http_client/src/models/middleware_request.dart';
import 'package:wyatt_http_client/src/models/middleware_response.dart';

/// {@template simple_logger_middleware}
/// A simple logger middleware that logs the request and response.
/// {@endtemplate}
class SimpleLoggerMiddleware
    with OnRequestMiddleware, OnResponseMiddleware
    implements Middleware {
  /// {@macro simple_logger_middleware}
  const SimpleLoggerMiddleware();

  @override
  String getName() => 'SimpleLogger';

  @override
  Future<MiddlewareRequest> onRequest(
    MiddlewareContext context,
    MiddlewareRequest request,
  ) async {
    final log = StringBuffer()
      ..writeln('${getName()}::OnRequest')
      ..writeln('>> ${request.method} ${request.url}');
    if (request.headers.isNotEmpty) {
      log.writeln('>> Headers:');
      request.headers.forEach((key, value) {
        log.writeln('>>   $key: $value');
      });
    }
    if (request.encodedBody.isNotEmpty) {
      log
        ..writeln('>> Body:')
        ..writeln(request.encodedBody);
    }
    print(log);

    return request;
  }

  @override
  Future<MiddlewareResponse> onResponse(
    MiddlewareContext context,
    MiddlewareResponse response,
  ) async {
    final log = StringBuffer()
      ..writeln('${getName()}::OnResponse')
      ..writeln('>> Status: ${response.status.name.toUpperCase()}')
      ..writeln('>> Length: ${response.contentLength ?? '0'} bytes');

    print(log);

    return response;
  }
}
